fcswrite
========

|PyPI Version| |Tests| |Coverage Status|


fcswrite allows you to write .fcs files, a file format used in flow cytometry.
Currently, fcswrite partially supports the FCS3.0 file format - Contributions
to fcswrite are welcome.


Compatibility
-------------
fcswrite is compatible to the following FCS file reading libraries:

- Python Flow Cytometry (FCM) Tools: `fcm <https://pypi.python.org/pypi/fcm>`__


Installation
------------
Install with pip:
::

    pip install fcswrite


Requirements:

- Python 2.7 or Python 3.x
- `numpy <https://github.com/numpy/numpy>`__


Testing
-------
Running tests

::

    python setup.py test

    

.. |PyPI Version| image:: http://img.shields.io/pypi/v/fcswrite.svg
   :target: https://pypi.python.org/pypi/fcswrite
.. |Tests| image:: http://img.shields.io/travis/ZELLMECHANIK-DRESDEN/fcswrite.svg
   :target: https://travis-ci.org/ZELLMECHANIK-DRESDEN/fcswrite
.. |Coverage Status| image:: https://img.shields.io/coveralls/ZELLMECHANIK-DRESDEN/fcswrite.svg
   :target: https://coveralls.io/r/ZELLMECHANIK-DRESDEN/fcswrite

